# SquareIt
Package should be used to square a number.

## How to install?

## Windows
pip install squareit

## Linux

sudo pip install squareit

## How to use?

### Initializing the package 

import squareit

### Use

Input any number you want to square.